@@ -48,13 +48,20 @@ struct _ClutterStageGLX
 {
   ClutterStageX11 parent_instance;
 
-  int pending_swaps;
+  gint pending_swaps;
 
   GLXPixmap glxpixmap;
   GLXWindow glxwin;
 
-  gboolean initialized_redraw_clip;
+  /* We only enable clipped redraws after 2 frames, since we've seen
+   * a lot of drivers can struggle to get going and may output some
+   * junk frames to start with.
+   */
+  guint frame_count;
+
   ClutterGeometry bounding_redraw_clip;
+
+  guint initialized_redraw_clip : 1;
 };
 
 struct _ClutterStageGLXClass
@@ -64,9 +71,6 @@ struct _ClutterStageGLXClass
 
 GType _clutter_stage_glx_get_type  (void) G_GNUC_CONST;
 
-void  _clutter_stage_glx_redraw    (ClutterStageGLX *stage_glx,
-                                   ClutterStage *stage);
-
 G_END_DECLS
 
 #endif /* __CLUTTER_STAGE_H__ */
