@@ -28,13 +28,15 @@
 #include <X11/Xatom.h>
 
 #include "clutter-x11.h"
+
 #include "clutter-backend-private.h"
 #include "clutter-keymap-x11.h"
+
 #include "xsettings/xsettings-client.h"
 
 G_BEGIN_DECLS
 
-#define CLUTTER_TYPE_BACKEND_X11                (clutter_backend_x11_get_type ())
+#define CLUTTER_TYPE_BACKEND_X11                (_clutter_backend_x11_get_type ())
 #define CLUTTER_BACKEND_X11(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLUTTER_TYPE_BACKEND_X11, ClutterBackendX11))
 #define CLUTTER_IS_BACKEND_X11(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLUTTER_TYPE_BACKEND_X11))
 #define CLUTTER_BACKEND_X11_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), CLUTTER_TYPE_BACKEND_X11, ClutterBackendX11Class))
@@ -43,23 +45,39 @@ G_BEGIN_DECLS
 
 typedef struct _ClutterBackendX11       ClutterBackendX11;
 typedef struct _ClutterBackendX11Class  ClutterBackendX11Class;
+typedef struct _ClutterEventX11         ClutterEventX11;
+typedef struct _ClutterX11EventFilter   ClutterX11EventFilter;
 
-typedef struct _ClutterX11EventFilter
+struct _ClutterX11EventFilter
 {
   ClutterX11FilterFunc func;
   gpointer             data;
 
-} ClutterX11EventFilter;
+};
+
+struct _ClutterEventX11
+{
+  /* additional fields for Key events */
+  gint key_group;
+
+  guint key_is_modifier : 1;
+  guint num_lock_set    : 1;
+  guint caps_lock_set   : 1;
+};
 
 struct _ClutterBackendX11
 {
   ClutterBackend parent_instance;
 
   Display *xdpy;
-  Window   xwin_root;
+  gchar   *display_name;
+
   Screen  *xscreen;
   int      xscreen_num;
-  gchar   *display_name;
+  int      xscreen_width;
+  int      xscreen_height;
+
+  Window   xwin_root;
 
   /* event source */
   GSource *event_source;
@@ -78,21 +96,18 @@ struct _ClutterBackendX11
   Atom atom_NET_WM_NAME;
   Atom atom_UTF8_STRING;
 
-  int xi_event_base;
-  int event_types[CLUTTER_X11_XINPUT_LAST_EVENT];
-  gboolean have_xinput;
-
   Time last_event_time;
 
   ClutterDeviceManager *device_manager;
+  gboolean has_xinput;
 
   XSettingsClient *xsettings;
   Window xsettings_xwin;
 
   ClutterKeymapX11 *keymap;
-  int xkb_event_base;
   gboolean use_xkb;
   gboolean have_xkb_autorepeat;
+  guint keymap_serial;
 };
 
 struct _ClutterBackendX11Class
@@ -105,51 +120,16 @@ struct _ClutterBackendX11Class
    * may need to be handled differently for different backends.
    */
   XVisualInfo *(* get_visual_info) (ClutterBackendX11 *backend);
-
-  /*
-   * Different X11 backends may care about some special events so they all have
-   * a chance to intercept them.
-   */
-  gboolean (*handle_event) (ClutterBackendX11 *backend,
-                            XEvent            *xevent);
 };
 
-/* platform-specific event data */
-typedef struct _ClutterEventX11 ClutterEventX11;
-
 void   _clutter_backend_x11_events_init (ClutterBackend *backend);
 void   _clutter_backend_x11_events_uninit (ClutterBackend *backend);
 
-GType clutter_backend_x11_get_type (void) G_GNUC_CONST;
+GType _clutter_backend_x11_get_type (void) G_GNUC_CONST;
 
 /* Private to glx/eglx backends */
-gboolean
-clutter_backend_x11_pre_parse (ClutterBackend  *backend,
-                               GError         **error);
-
-gboolean
-clutter_backend_x11_post_parse (ClutterBackend  *backend,
-                                GError         **error);
-
-gboolean
-clutter_backend_x11_init_stage (ClutterBackend  *backend,
-                                GError         **error);
-
-ClutterActor *
-clutter_backend_x11_get_stage (ClutterBackend *backend);
-
-void
-clutter_backend_x11_add_options (ClutterBackend *backend,
-                                 GOptionGroup   *group);
-
-ClutterFeatureFlags
-clutter_backend_x11_get_features (ClutterBackend *backend);
-
 XVisualInfo *
-clutter_backend_x11_get_visual_info (ClutterBackendX11 *backend_x11);
-
-ClutterInputDevice *
-_clutter_x11_get_device_for_xid (XID id);
+_clutter_backend_x11_get_visual_info (ClutterBackendX11 *backend_x11);
 
 void
 _clutter_x11_select_events (Window xwin);
@@ -163,6 +143,14 @@ _clutter_event_x11_copy (ClutterEventX11 *event_x11);
 void
 _clutter_event_x11_free (ClutterEventX11 *event_x11);
 
+gboolean
+_clutter_x11_input_device_translate_screen_coord (ClutterInputDevice *device,
+                                                  gint                stage_root_x,
+                                                  gint                stage_root_y,
+                                                  guint               index_,
+                                                  gdouble             value,
+                                                  gdouble            *axis_value);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_BACKEND_X11_H__ */
